/*
 | Job Scheduler Tables for Notification for PostgreSQL
 | SOS GmbH, 2018-11-09, robert.ehrlich@sos-berlin.com
*/

/* Table for SCHEDULER_MON_SYSRESULTS */
CREATE OR REPLACE FUNCTION tmp() RETURNS VOID AS $$ 
DECLARE table_exist integer; 
BEGIN 
    SELECT COUNT(*) INTO table_exist FROM INFORMATION_SCHEMA.TABLES WHERE  UPPER(TABLE_NAME)='SCHEDULER_MON_SYSRESULTS' AND TABLE_CATALOG=CURRENT_DATABASE() AND TABLE_SCHEMA=CURRENT_SCHEMA(); 
    IF table_exist = 0 THEN 
        EXECUTE 'CREATE TABLE SCHEDULER_MON_SYSRESULTS(
                "ID"                    BIGINT          NOT NULL,
                "SYS_NOTIFICATION_ID"   BIGINT          NOT NULL,
                "NOTIFICATION_ID"       BIGINT          NOT NULL,
                "ORDER_STEP"            BIGINT          NOT NULL,
                "ORDER_STEP_STATE"      VARCHAR(100)    NOT NULL,
                "CURRENT_NOTIFICATION"  BIGINT          NOT NULL,
                "RECOVERED"             NUMERIC(1)      NOT NULL,
                "CREATED"               TIMESTAMP       NOT NULL,
                "MODIFIED"              TIMESTAMP       NOT NULL,
                CONSTRAINT SCHEDULER_MSR_UNIQ UNIQUE("SYS_NOTIFICATION_ID","NOTIFICATION_ID"),
                PRIMARY KEY ("ID")
            )'; 
        DECLARE table_n_exist integer; 
        BEGIN 
            SELECT COUNT(*) INTO table_n_exist FROM INFORMATION_SCHEMA.TABLES WHERE  UPPER(TABLE_NAME)='SCHEDULER_MON_CHECKS' AND TABLE_CATALOG=CURRENT_DATABASE() AND TABLE_SCHEMA=CURRENT_SCHEMA(); 
            IF table_n_exist > 0 THEN 
                EXECUTE 'TRUNCATE TABLE SCHEDULER_MON_CHECKS;';
            END IF; 
        END;
        DECLARE table_n_exist integer; 
        BEGIN 
            SELECT COUNT(*) INTO table_n_exist FROM INFORMATION_SCHEMA.TABLES WHERE  UPPER(TABLE_NAME)='SCHEDULER_MON_NOTIFICATIONS' AND TABLE_CATALOG=CURRENT_DATABASE() AND TABLE_SCHEMA=CURRENT_SCHEMA(); 
            IF table_n_exist > 0 THEN 
                EXECUTE 'TRUNCATE TABLE SCHEDULER_MON_NOTIFICATIONS;';
            END IF; 
        END;
        DECLARE table_n_exist integer; 
        BEGIN 
            SELECT COUNT(*) INTO table_n_exist FROM INFORMATION_SCHEMA.TABLES WHERE  UPPER(TABLE_NAME)='SCHEDULER_MON_SYSNOTIFICATIONS' AND TABLE_CATALOG=CURRENT_DATABASE() AND TABLE_SCHEMA=CURRENT_SCHEMA(); 
            IF table_n_exist > 0 THEN 
                EXECUTE 'TRUNCATE TABLE SCHEDULER_MON_SYSNOTIFICATIONS;';
            END IF; 
        END;
        DECLARE table_n_exist integer; 
        BEGIN 
            SELECT COUNT(*) INTO table_n_exist FROM INFORMATION_SCHEMA.TABLES WHERE  UPPER(TABLE_NAME)='SCHEDULER_MON_RESULTS' AND TABLE_CATALOG=CURRENT_DATABASE() AND TABLE_SCHEMA=CURRENT_SCHEMA(); 
            IF table_n_exist > 0 THEN 
                EXECUTE 'TRUNCATE TABLE SCHEDULER_MON_RESULTS;';
            END IF; 
        END;
        EXECUTE 'CREATE INDEX SCHEDULER_MSR_OS ON SCHEDULER_MON_SYSRESULTS("ORDER_STEP")';
        DECLARE sequence_exist integer; 
        BEGIN 
            SELECT COUNT(*) INTO sequence_exist FROM pg_class, pg_namespace WHERE UPPER(pg_class.relname) = 'SCHEDULER_MON_SYSR_ID_SEQ' AND pg_namespace.oid = pg_class.relnamespace AND pg_namespace.nspname = current_schema; 
            IF sequence_exist = 0 THEN 
                EXECUTE 'CREATE SEQUENCE SCHEDULER_MON_SYSR_ID_SEQ;';
            END IF; 
        END;
    END IF; 
RETURN; 
END; $$ LANGUAGE plpgsql;
SELECT tmp();
COMMIT;

/* clean-up temporary objects */
DROP FUNCTION tmp();
COMMIT;